return_error

Function return_error 

pub fn return_error<F>(callback: F) -> ReturnError<F>
where F: Fn(&PaverEvent) -> Result<(), Status>,
A Hook for the specific case where you want to return an error.

If the callback returns ZX_OK, the Hook will pass the request off to the next Hook. Responds to both BootManagerRequests and DataSinkRequests.